@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moose;
 use namespace::autoclean;
@@ -47,6 +47,8 @@ sub after_build {
             push @badges, "[![Coverage Status](https://coveralls.io/repos/$user_name/$repository_name/badge.png?branch=master)](https://coveralls.io/r/$user_name/$repository_name?branch=master)"
         } elsif ($badge eq 'gitter') {
             push @badges, "[![Gitter chat](https://badges.gitter.im/$user_name/$repository_name.png)](https://gitter.im/$user_name/$repository_name)";
+        } elsif ($badge eq 'cpants') {
+            push @badges, "![](http://cpants.cpanauthors.org/dist/$repository_name.png)";
         }
     }
 
@@ -88,7 +90,7 @@ Dist::Zilla::Plugin::GitHubREADME::Badge is to add badges in github README.md
 
 =head2 badges
 
-Currently only travis, coveralls and gitter are supported. but patches welcome.
+Currently only travis, coveralls, gitter and cpants are supported. but patches welcome.
 
 default goes to travis and coveralls.
 
@@ -96,6 +98,7 @@ default goes to travis and coveralls.
     badges = travis
     badges = coveralls
     badges = gitter
+    badges = cpants
 
 =head2 place
 
